@@ -13,4 +13,8 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 '''
-from CiscoAutomationFramework.Parsers.ConfigParser import ConfigParser
\ No newline at end of file
+from CiscoAutomationFramework.Parsers.ConfigParser import ConfigParser
+from CiscoAutomationFramework.Parsers.RoutingTableParser import RoutingTableParser
+from CiscoAutomationFramework.Parsers.CDPparser import CDPparser
+from CiscoAutomationFramework.Parsers.PowerInlineParser import PowerInlineParser
+from CiscoAutomationFramework.Parsers.MacAddressTableParser import MacAddressTableParser
\ No newline at end of file
